==> fortawesome__react-fontawesome-0.1.8.jar: META-INF/resources/webjars/fortawesome__react-fontawesome/0.1.8/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/) and this project adheres to [Semantic Versioning](http://semver.org/).

---

## [0.1.8](https://github.com/FortAwesome/react-fontawesome/releases/tag/0.1.8) - 2019-12-06

### Fixed

- Add swapOpacity to Typescript definitions #308

---

## [0.1.7](https://github.com/FortAwesome/react-fontawesome/releases/tag/0.1.7) - 2019-10-19

### Fixed

- Add DOM attributes to FontAwesomeIconProps to Typescript definitions #151 #196

---

## [0.1.6](https://github.com/FortAwesome/react-fontawesome/releases/tag/0.1.6) - 2019-10-10

### Fixed

- Ignore null values for pull, rotation, and size props #289

---

## [0.1.5](https://github.com/FortAwesome/react-fontawesome/releases/tag/0.1.5) - 2019-09-29

### Added

- Full support for Duotone icons

---

## [0.1.4](https://github.com/FortAwesome/react-fontawesome/releases/tag/0.1.4) - 2019-01-15

### Changed

- Upgrade to Babel 7 and Rollup 1 #213

### Fixed

- Thrown error in IE11

---

## [0.1.3](https://github.com/FortAwesome/react-fontawesome/releases/tag/0.1.3) - 2018-09-06

### Added

- Add title prop #180

---

## [0.1.2](https://github.com/FortAwesome/react-fontawesome/releases/tag/0.1.2) - 2018-08-12

### Changed

- Better table of contents in README.md #172

---

## [0.1.1](https://github.com/FortAwesome/react-fontawesome/releases/tag/0.1.1) - 2018-08-07

### Changed

- Added tabIndex to TypeScript definitions #168

---

## [0.1.0](https://github.com/FortAwesome/react-fontawesome/releases/tag/0.1.0) - 2018-06-20

### Changed

- Upgraded to the newer Font Awesome 5.1 packages

---

## [0.0.20](https://github.com/FortAwesome/react-fontawesome/releases/tag/0.0.20) - 2018-05-15

### Added

- Added displayName to FontAwesomeIcon component

---

## [0.0.19](https://github.com/FortAwesome/react-fontawesome/releases/tag/0.0.19) - 2018-04-29

### Changed

- Moved prop-types from peerDependencies to dependencies #87

---

## [0.0.18](https://github.com/FortAwesome/react-fontawesome/releases/tag/0.0.18) - 2018-03-23

### Fixed

- Peer dependency warnings #103

---

## [0.0.17](https://github.com/FortAwesome/react-fontawesome/releases/tag/0.0.17) - 2017-12-19

### Changed

- Documentation and example improvements
- Use cross-env to support Windows
- Support for @fortawesome/fontawesome 1.1.0

---

## [0.0.16](https://github.com/FortAwesome/react-fontawesome/releases/tag/0.0.16) - 2017-12-09

### Changed

- Better documentation in the README

---

## [0.0.15](https://github.com/FortAwesome/react-fontawesome/releases/tag/0.0.15) - 2017-12-08

### Fixed

- Missing icons no longer return `undefined` which caused React to be noisy about a misbehaving component

==> fortawesome__react-fontawesome-0.1.10.jar: META-INF/resources/webjars/fortawesome__react-fontawesome/0.1.10/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/) and this project adheres to [Semantic Versioning](http://semver.org/).

---

## [0.1.10](https://github.com/FortAwesome/react-fontawesome/releases/tag/0.1.10) - 2020-06-02

### Added

- Support for forward ref #341

---

## [0.1.9](https://github.com/FortAwesome/react-fontawesome/releases/tag/0.1.9) - 2020-03-05

### Fixed

- Have FontAwesomeIconProps interface extend SVGAttributes, fixes #324

---

## [0.1.8](https://github.com/FortAwesome/react-fontawesome/releases/tag/0.1.8) - 2019-12-06

### Fixed

- Add swapOpacity to Typescript definitions #308

---

## [0.1.7](https://github.com/FortAwesome/react-fontawesome/releases/tag/0.1.7) - 2019-10-19

### Fixed

- Add DOM attributes to FontAwesomeIconProps to Typescript definitions #151 #196

---

## [0.1.6](https://github.com/FortAwesome/react-fontawesome/releases/tag/0.1.6) - 2019-10-10

### Fixed

- Ignore null values for pull, rotation, and size props #289

---

## [0.1.5](https://github.com/FortAwesome/react-fontawesome/releases/tag/0.1.5) - 2019-09-29

### Added

- Full support for Duotone icons

---

## [0.1.4](https://github.com/FortAwesome/react-fontawesome/releases/tag/0.1.4) - 2019-01-15

### Changed

- Upgrade to Babel 7 and Rollup 1 #213

### Fixed

- Thrown error in IE11

---

## [0.1.3](https://github.com/FortAwesome/react-fontawesome/releases/tag/0.1.3) - 2018-09-06

### Added

- Add title prop #180

---

## [0.1.2](https://github.com/FortAwesome/react-fontawesome/releases/tag/0.1.2) - 2018-08-12

### Changed

- Better table of contents in README.md #172

---

## [0.1.1](https://github.com/FortAwesome/react-fontawesome/releases/tag/0.1.1) - 2018-08-07

### Changed

- Added tabIndex to TypeScript definitions #168

---

## [0.1.0](https://github.com/FortAwesome/react-fontawesome/releases/tag/0.1.0) - 2018-06-20

### Changed

- Upgraded to the newer Font Awesome 5.1 packages

---

## [0.0.20](https://github.com/FortAwesome/react-fontawesome/releases/tag/0.0.20) - 2018-05-15

### Added

- Added displayName to FontAwesomeIcon component

---

## [0.0.19](https://github.com/FortAwesome/react-fontawesome/releases/tag/0.0.19) - 2018-04-29

### Changed

- Moved prop-types from peerDependencies to dependencies #87

---

## [0.0.18](https://github.com/FortAwesome/react-fontawesome/releases/tag/0.0.18) - 2018-03-23

### Fixed

- Peer dependency warnings #103

---

## [0.0.17](https://github.com/FortAwesome/react-fontawesome/releases/tag/0.0.17) - 2017-12-19

### Changed

- Documentation and example improvements
- Use cross-env to support Windows
- Support for @fortawesome/fontawesome 1.1.0

---

## [0.0.16](https://github.com/FortAwesome/react-fontawesome/releases/tag/0.0.16) - 2017-12-09

### Changed

- Better documentation in the README

---

## [0.0.15](https://github.com/FortAwesome/react-fontawesome/releases/tag/0.0.15) - 2017-12-08

### Fixed

- Missing icons no longer return `undefined` which caused React to be noisy about a misbehaving component
